@@ -139,7 +139,7 @@ def get_tables(**kwargs: Any) -> List[dict]:
     return boto3.client("glue").get_paginator("get_tables").paginate(**kwargs).build_full_result()["TableList"]
 
 
-def recreate_db(**kwargs: Any) -> None:
+def recreate_database(**kwargs: Any) -> None:
     """Safely delete and create the specified AWS Glue database.
 
     At minimum the `Name` keyword argument is required.
